""" 

Context : SRP
Module  : MCMC (Monte Carlo Markov Chain)
Version : 1.1.0
Author  : Stefano Covino
Date    : 21/08/2020
E-mail  : stefano.covino@brera.inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino


Usage   : to be imported

Remarks :

History : (10/08/2020) First version.
        : (21/08/2020) ptmcee_run added.
"""



__all__ = ['emcee_run', 'ptemcee_run', 'quartile']

