""" 

Context : SRP
Module  : GP
Version : 1.0.0
Author  : Stefano Covino
Date    : 30/01/2020
E-mail  : stefano.covino@brera.inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino


Usage   : to be imported

Remarks :

History : (30/01/2020) First version.
"""



__all__ = ['AEKernel', 'CosineKernel', 'ExpSineKernel',
            'MaternKernel', 'PSDMatern', 'PSDSE', 'RQKernel',
            'SEKernel']

