""" 

Context : SRP
Module  : FT (Fourier Transform)
Version : 1.0.0
Author  : Stefano Covino
Date    : 03/02/2020
E-mail  : stefano.covino@brera.inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino


Usage   : to be imported

Remarks :

History : (03/02/2020) First version.
"""



__all__ = ['ACF', 'fftransform', 'FourierPeriodogram']

